==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/CATALOGREFERENCEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CATALOGREFERENCEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CATALOGREFERENCEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SUPPLIERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SUPPLIERPARTCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CATALOGREFERENCEID_Type", propOrder = {
    "partid",
    "supplierid",
    "supplierpartcode"
})
public class CATALOGREFERENCEID_Type {

    @XmlElement(name = "PARTID", required = true)
    protected PARTID_Type partid;
    @XmlElement(name = "SUPPLIERID", required = true)
    protected SUPPLIERID_Type supplierid;
    @XmlElement(name = "SUPPLIERPARTCODE", required = true)
    protected String supplierpartcode;

    /**
     * Obtient la valeur de la propriété partid.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Définit la valeur de la propriété partid.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Obtient la valeur de la propriété supplierid.
     * 
     * @return
     *     possible object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public SUPPLIERID_Type getSUPPLIERID() {
        return supplierid;
    }

    /**
     * Définit la valeur de la propriété supplierid.
     * 
     * @param value
     *     allowed object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public void setSUPPLIERID(SUPPLIERID_Type value) {
        this.supplierid = value;
    }

    /**
     * Obtient la valeur de la propriété supplierpartcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSUPPLIERPARTCODE() {
        return supplierpartcode;
    }

    /**
     * Définit la valeur de la propriété supplierpartcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSUPPLIERPARTCODE(String value) {
        this.supplierpartcode = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/CATALOGREFERENCEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CATALOGREFERENCEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CATALOGREFERENCEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SUPPLIERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SUPPLIERPARTCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CATALOGREFERENCEID_Type", propOrder = {
    "partid",
    "supplierid",
    "supplierpartcode"
})
public class CATALOGREFERENCEID_Type {

    @XmlElement(name = "PARTID", required = true)
    protected PARTID_Type partid;
    @XmlElement(name = "SUPPLIERID", required = true)
    protected SUPPLIERID_Type supplierid;
    @XmlElement(name = "SUPPLIERPARTCODE", required = true)
    protected String supplierpartcode;

    /**
     * Gets the value of the partid property.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Sets the value of the partid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Gets the value of the supplierid property.
     * 
     * @return
     *     possible object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public SUPPLIERID_Type getSUPPLIERID() {
        return supplierid;
    }

    /**
     * Sets the value of the supplierid property.
     * 
     * @param value
     *     allowed object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public void setSUPPLIERID(SUPPLIERID_Type value) {
        this.supplierid = value;
    }

    /**
     * Gets the value of the supplierpartcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSUPPLIERPARTCODE() {
        return supplierpartcode;
    }

    /**
     * Sets the value of the supplierpartcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSUPPLIERPARTCODE(String value) {
        this.supplierpartcode = value;
    }

}
